/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nLanguage: ru\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "ImportExportDefinition, ImportExportDefinitions"
: [
  ""
 ,""
 ,""
 ,""

]
, "Application, Applications"
: [
  "Приложение"
 ,"Приложения"
 ,"Приложения"
 ,"Приложения"

]
, "User, Users"
: [
  "Пользователь"
 ,"Пользователя"
 ,"Пользователей"
 ,"Пользователей"

]
, "Groups"
: "Группы"

, "Roles"
: "Роли"

, "Applications"
: "Приложения"

, "Containers"
: "Контейнеры"

, "Shared Tags"
: "Общие тэги"

, "Customfields"
: "Настраиваемые поля"

, "Computers"
: "Компьютеры"

, "Access Log, Access Logs"
: [
  "Журнал доступа"
 ,"Журналы доступа"
 ,"Журналы доступа"
 ,"Журналы доступа"

]
, "Log"
: ""

, "Server Information"
: "Информация о сервере"

, "ActiveSync Devices"
: "Устройства с поддержкой Active Sync"

, "E-mail Accounts"
: ""

, "Import Export Definitions"
: ""

, "Admin"
: "Администратор"

, "Refresh"
: "Обновить"

, "Disabled"
: ""

, "Feature is disabled by configuration."
: ""

, "Default Addressbook for new contacts and groups"
: "Адресная книга по умолчанию для новых контактов и групп"

, "Computer Name"
: "Имя компьютера"

, "Config, Configs"
: [
  "Настройка"
 ,"Настройки"
 ,"Настройки"
 ,"Настройки"

]
, "Description"
: "Описание"

, "Name"
: "Имя"

, "Label"
: "Метка"

, "Value"
: "Значение"

, "Default ({0})"
: "По умолчанию ({0})"

, "Yes"
: "Да"

, "No"
: "Нет"

, "Group Name"
: "Название группы"

, "Visibility"
: "Видимость"

, "Display in addressbook"
: "Отображать в адресной книге"

, "Hide from addressbook"
: "Скрыть в адресной книги"

, "Saved in Addressbook"
: "Сохранено в адресную книгу"

, "E-mail"
: ""

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: "Члены группы"

, "Domain is not allowed. Check your SMTP domain configuration."
: "Домен недопустим. Пожалуйста, проверьте настройки домена в конфигурации SMTP"

, "Confirm"
: "Подтвердить"

, "Do you really want to delete the selected tags?"
: "Вы действительно хотите удалить выбранные тэги?"

, "Deleting tag(s)..."
: "Удаление тэга(ов)..."

, "Add Tag"
: "Добавить тег"

, "Edit Tag"
: "Изменить тег"

, "Delete Tag"
: "Удалить тег"

, "Search:"
: "Поиск:"

, "Displaying tags {0} - {1} of {2}"
: "Показаны тэги {0} - {1} из {2}"

, "No tags to display"
: "Нет тэгов"

, "ID"
: "ID"

, "Color"
: "Цвет"

, "Usage:&#160;"
: "Использование:&#160;"

, "Do you really want to delete the selected roles?"
: "Вы действительно хотите удалить выбранные роли?"

, "Deleting role(s)..."
: "Удаление роли(ей)..."

, "Failed"
: "Неудача"

, "Some error occurred while trying to delete the role."
: "При удаление роли произошла ошибка."

, "Add Role"
: "Добавить роль"

, "Edit Role"
: "Изменить роль"

, "Delete Role"
: "Удалить роль"

, "Displaying roles {0} - {1} of {2}"
: "Показаны роли {0} - {1} из {2}"

, "No roles to display"
: "Нет ролей"

, "Container Name"
: "Имя контейнера"

, "Type"
: "Тип"

, "Container Order"
: "Порядок контейнеров"

, "Container, Containers"
: [
  "Контейнер"
 ,"Контейнеры"
 ,"Контейнеры"
 ,"Контейнеры"

]
, "Model"
: "Модель"

, "personal"
: "личный"

, "shared"
: "общий"

, "Order"
: "Порядок"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: "Примечание владельца"

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Do you really want to delete the selected groups?"
: "Вы уверены что хотите удалить выбранные группы?"

, "Deleting group(s)..."
: "Удаление групп(ы)..."

, "Some error occurred while trying to delete the group."
: "При удаление группы произошла ошибка."

, "Add Group"
: "Добавить группу"

, "Edit Group"
: "Изменить группу"

, "Delete Group"
: "Удалить группу"

, "Displaying groups {0} - {1} of {2}"
: "Показаны группы {0} - {1} из {2}"

, "No groups to display"
: "Нет групп"

, "Account only"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "IP Address"
: "IP адрес"

, "Login Time"
: "Время регистрации"

, "Logout Time"
: "Время выхода из системы"

, "Client Type"
: "Тип клиента"

, "Session ID"
: "ID сессии"

, "Login Name"
: "Имя для регистрации"

, "Result"
: "Результат"

, "User Agent"
: ""

, "user blocked"
: "пользователь заблокирован"

, "password expired"
: "истек срок пароля"

, "user disabled"
: "пользователь отключен"

, "invalid password"
: "неверный пароль"

, "ambiguous username"
: "Имя пользователя многозначно"

, "user not found"
: "пользователь не найден"

, "failure"
: "неудачно"

, "success"
: "успешно"

, "Customfield, Customfields"
: [
  "Настраиваемые поля"
 ,"Настраиваемые поля"
 ,"Настраиваемые поля"
 ,"Настраиваемые поля"

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Errors"
: "Ошибки"

, "Please configure store for this field type"
: "Пожалуйста, настройте хранилище для этого типа поля"

, "Record Class"
: "Класс записей"

, "Given record class not found"
: "Данный класс записи не найден"

, "Cancel"
: "Отмена"

, "OK"
: "OK"

, "Configure store"
: "Настроить хранилище"

, "Custom field definition"
: "Пользовательское поле определений"

, "Text"
: "Текст"

, "Textarea"
: ""

, "Number"
: "Номер"

, "Date"
: "Дата"

, "DateTime"
: "Время"

, "Time"
: "Время"

, "Boolean"
: "Булево"

, "Search Combo"
: "Составной поиск"

, "Key Field"
: "Ключевое поле"

, "Record"
: "Запись"

, "Record List"
: ""

, "Length"
: "Длина"

, "Required"
: "Требуется"

, "Custom field additional properties"
: "Пользовательские поля дополнительных свойств"

, "Tab Panel"
: ""

, "Group, Groups"
: [
  "Группа"
 ,"Группы"
 ,"Группы"
 ,"Группы"

]
, "Key"
: ""

, "Customfield already exists. Please choose another name."
: "Это настраиваемое поле уже существует. Пожалуйста, используйте другое имя."

, "Enable Account"
: "включить учётную запись"

, "Disable Account"
: "отключить учётную запись"

, "Reset Password"
: "Сбросить пароль"

, "Status"
: "Статус"

, "Display name"
: "Отображать как"

, "Login name"
: "Имя пользователя"

, "Last name"
: "Фамилия"

, "First name"
: "Имя"

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "OpenID"
: "OpenID"

, "Last login at"
: "Последний регистрировался в"

, "Last login from"
: "Последняя регистрация от"

, "Password Must Change"
: "Пароль должен быть изменен"

, "Password changed"
: "Пароль изменен"

, "Expires"
: "Истекает"

, "Set new password"
: "Задать новый пароль"

, "Please enter the new password:"
: "Пожалуйста, введите новый пароль:"

, "Users"
: "Пользователи"

, "Samba User, Samba Users"
: [
  "Пользователь Samba"
 ,"Пользователя Samba"
 ,"Пользователей Samba"
 ,"Пользователей Samba"

]
, "Email User, Email Users"
: [
  "Электронные адреса пользователей"
 ,"Электронные адреса пользователей"
 ,"Электронные адреса пользователей"
 ,"Электронные адреса пользователей"

]
, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: "Пароли не совпадают!"

, "Passwords match!"
: "Пароли совпадают!"

, "Primary group"
: "Основная группа"

, "Unix"
: "Unix"

, "Home Directory"
: "Домашний каталог"

, "Login Shell"
: "Оболочка"

, "Windows"
: "Windows"

, "Home Drive"
: "Домашний диск"

, "never logged in"
: "никогда не регистрировался"

, "Home Path"
: "Домашний путь"

, "never logged off"
: "никогда не регистрировался"

, "Profile Path"
: "Путь профиля"

, "Password Last Set"
: "Последняя установка пароля"

, "never"
: "никогда"

, "Logon Script"
: "Скрипт входа"

, "Password Can Change"
: "Пароль может быть изменен"

, "not set"
: "не задан"

, "Kick Off Time"
: "Время начала"

, "Filesystem Quota"
: ""

, "Quota"
: "Квота"

, "no quota set"
: "квота не задана"

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: "Размер почтового ящика"

, "Sieve Quota"
: ""

, "Current Sieve size"
: "Размер Sieve"

, "Information"
: "Информация"

, "Last Login"
: "Последний вход"

, "Forward Only"
: "Только пересылка"

, "E-mail Alias"
: ""

, "Add an alias address..."
: "Добавить псевдоним..."

, "This alias can be used for sending e-mails."
: ""

, "Domain not allowed"
: "Домен недопустим"

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: "Домен {0} псевдонима {1}, который вы пытаетесь добавить, не является ни основным, ни дополнительным. Пожалуйста добавьте этот домен во второстепенные домены в настройках SMTP или используйте другой домен."

, "Forwarding to self"
: "Пересылка себе"

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Password confirmation"
: "Подтверждение пароля"

, "Repeat password"
: "Повтор пароля"

, "Ok"
: "Ok"

, "Account"
: "Учётная запись"

, "Password"
: "Пароль"

, "Multi Factor Authentication Config"
: ""

, "enabled"
: "включено"

, "disabled"
: "отключено"

, "expired"
: "завершённый"

, "blocked"
: "заблокирован"

, "Invalid Status"
: "Некорректный статус"

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: "Статус \"заблокировано\" будет стоять только в том случае, если пользователь часто ошибался с вводом пароля. Выставить этот статус здесь невозможно."

, "don't know"
: "неизвестно"

, "Password set"
: "Пароль установлен"

, "User groups"
: "Группы пользователей"

, "User roles"
: "Роли пользователей"

, "Fileserver"
: "Файловый сервер"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "Computer, Computers"
: [
  "Компьютер"
 ,"Компьютера"
 ,"Компьютеров"
 ,"Компьютеров"

]
, "Please wait"
: "Пожалуйста, подождите"

, "Updating Memberships"
: "Обновить членство"

, "Could not save role."
: "Не удалось сохранить роль."

, "Please fix the errors noted."
: "Пожалуйста, устраните отмеченные ошибки."

, "Deleting role..."
: "Удаление роли..."

, "Rights"
: "Права"

, "Members"
: "Участники"

, "Role Name"
: "Название роли"

, "Transferring {0}..."
: "Передано {0}..."

, "Role"
: "Роль"

, "Add New Role"
: "Добавьте новую роль"

, "Edit Role \"{0}\""
: "Изменить роль \"{0}\""

, "Configs"
: "Настройки"

, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Updating Tag"
: "Обновление тега"

, "Could not save tag ({0})"
: "Тег ({0}) не сохранён"

, "Allowed Contexts"
: "Разрешённый контекст"

, "Context"
: "Контекст"

, "Account Rights"
: "Права учётной записи"

, "View"
: "Представление"

, "Use"
: "Использовать"

, "Tag Name"
: "Название тэга"

, "Tag"
: "Тег"

, "Add New Tag"
: "Добавить новый тэг"

, "Edit Tag \"{0}\""
: "Изменить тэг \"{0}\""

, "Enable Application"
: "Включить приложение"

, "Disable Application"
: "Отключить приложение"

, "Settings"
: "Настройки"

, "{0} Settings"
: "{0} Настройки"

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: "Показаны приложения {0} - {1} из {2}"

, "No applications to display"
: "Нет приложений"

, "Version"
: "Версия"

, "Default password must change for new user settings"
: ""

, "Default IMAP user settings"
: "Пользовательские настройки IMAP по-умолчанию."

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: "Ваш контейнер изменён"

, "Your container has been changed by %1$s %2$sNote: %3$s"
: "Ваш контейнер изменён %1$s %2$sПримечание: %3$s"

, "Password is needed for system account creation"
: ""

, "Notifications"
: ""

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "Manage import and export definitions"
: ""

, "Add and edit import and export definitions"
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""

, "view ImportExportDefinitions"
: ""












































, "ImportExportDefinition"
: ""

, "Application"
: "Приложение"

, "User"
: "Пользователь"

, "Access Log"
: "Журнал доступа"

, "Config"
: "Настройка"

, "Container"
: "Контейнер"

, "Customfield"
: "Настраиваемые поля"

, "Group"
: "Группа"

, "Samba User"
: "Пользователь Samba"

, "Email User"
: "Электронные адреса пользователей"

, "Computer"
: "Компьютер"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
